@@ -1,7 +1,8 @@
 use std::sync::Arc;
 
+use vortex_dtype::field::Field;
 use vortex_dtype::DType;
-use vortex_error::{vortex_bail, VortexError, VortexResult};
+use vortex_error::{vortex_bail, vortex_err, VortexError, VortexExpect, VortexResult};
 
 use crate::value::ScalarValue;
 use crate::Scalar;
@@ -83,6 +84,34 @@ impl<'a> StructScalar<'a> {
             Ok(Scalar::null(dtype.clone()))
         }
     }
+
+    pub fn project(&self, projection: &[Field]) -> VortexResult<Scalar> {
+        let struct_dtype = self
+            .dtype
+            .as_struct()
+            .ok_or_else(|| vortex_err!("Not a struct dtype"))?;
+        let projected_dtype = struct_dtype.project(projection)?;
+        let new_fields = if let Some(fs) = self.fields() {
+            ScalarValue::List(
+                projection
+                    .iter()
+                    .map(|p| match p {
+                        Field::Name(n) => struct_dtype
+                            .find_name(n)
+                            .vortex_expect("DType has been successfully projected already"),
+                        Field::Index(i) => *i,
+                    })
+                    .map(|i| fs[i].clone())
+                    .collect(),
+            )
+        } else {
+            ScalarValue::Null
+        };
+        Ok(Scalar::new(
+            DType::Struct(projected_dtype, self.dtype().nullability()),
+            new_fields,
+        ))
+    }
 }
 
 impl Scalar {
