@@ -1,5 +1,5 @@
 use std::future::{ready, Future};
-use std::io;
+use std::io::{self, Cursor, Write};
 
 use vortex_buffer::io_buf::IoBuf;
 
@@ -24,6 +24,23 @@ impl VortexWrite for Vec<u8> {
     }
 }
 
+impl<T> VortexWrite for Cursor<T>
+where
+    Cursor<T>: Write,
+{
+    fn write_all<B: IoBuf>(&mut self, buffer: B) -> impl Future<Output = io::Result<B>> {
+        ready(std::io::Write::write_all(self, buffer.as_slice()).map(|_| buffer))
+    }
+
+    fn flush(&mut self) -> impl Future<Output = io::Result<()>> {
+        ready(std::io::Write::flush(self))
+    }
+
+    fn shutdown(&mut self) -> impl Future<Output = io::Result<()>> {
+        ready(Ok(()))
+    }
+}
+
 impl<W: VortexWrite> VortexWrite for &mut W {
     fn write_all<B: IoBuf>(&mut self, buffer: B) -> impl Future<Output = io::Result<B>> {
         (*self).write_all(buffer)
